@@ -202,3 +202,7 @@ ADD = 'ADD'
 ATTR_UPDATE_ACTIONS = [PUT, DELETE, ADD]
 BATCH_GET_PAGE_LIMIT = 100
 BATCH_WRITE_PAGE_LIMIT = 25
+
+META_CLASS_NAME = "Meta"
+REGION = "region"
+HOST = "host"
