@@ -1,12 +1,11 @@
 """
 Test model API
 """
+import six
 import copy
+import collections
 from datetime import datetime
 from unittest import TestCase
-
-import six
-
 from pynamodb.throttle import Throttle
 from pynamodb.connection.util import pythonic
 from pynamodb.exceptions import TableError
@@ -27,7 +26,8 @@ from .response import HttpOK, HttpBadRequest
 from .data import (
     MODEL_TABLE_DATA, GET_MODEL_ITEM_DATA, SIMPLE_MODEL_TABLE_DATA,
     BATCH_GET_ITEMS, SIMPLE_BATCH_GET_ITEMS, COMPLEX_TABLE_DATA,
-    COMPLEX_ITEM_DATA, INDEX_TABLE_DATA, LOCAL_INDEX_TABLE_DATA
+    COMPLEX_ITEM_DATA, INDEX_TABLE_DATA, LOCAL_INDEX_TABLE_DATA,
+    CUSTOM_ATTR_NAME_INDEX_TABLE_DATA, CUSTOM_ATTR_NAME_ITEM_DATA
 )
 
 
@@ -44,7 +44,7 @@ SESSION_PATCH_METHODD = 'botocore.session.get_session'
 
 
 class OldStyleModel(Model):
-    table_name = 'IndexedModel'
+    _table_name = 'IndexedModel'
     user_name = UnicodeAttribute(hash_key=True)
 
 
@@ -119,7 +119,7 @@ class SimpleUserModel(Model):
     user_name = UnicodeAttribute(hash_key=True)
     email = UnicodeAttribute()
     numbers = NumberSetAttribute()
-    aliases = UnicodeSetAttribute()
+    custom_aliases = UnicodeSetAttribute(attr_name='aliases')
     icons = BinarySetAttribute()
     views = NumberAttribute(null=True)
 
@@ -135,13 +135,33 @@ class ThrottledUserModel(Model):
     throttle = Throttle('50')
 
 
+class CustomAttrIndex(LocalSecondaryIndex):
+    class Meta:
+        read_capacity_units = 2
+        write_capacity_units = 1
+        projection = AllProjection()
+    overidden_uid = UnicodeAttribute(hash_key=True, attr_name='user_id')
+
+
+class CustomAttrNameModel(Model):
+    """
+    A testing model
+    """
+    class Meta:
+        table_name = 'CustomAttrModel'
+    overidden_user_name = UnicodeAttribute(hash_key=True, attr_name='user_name')
+    overidden_user_id = UnicodeAttribute(range_key=True, attr_name='user_id')
+    overidden_attr = UnicodeAttribute(attr_name='foo_attr', null=True)
+    uid_index = CustomAttrIndex()
+
+
 class UserModel(Model):
     """
     A testing model
     """
     class Meta:
         table_name = 'UserModel'
-    user_name = UnicodeAttribute(hash_key=True)
+    custom_user_name = UnicodeAttribute(hash_key=True, attr_name='user_name')
     user_id = UnicodeAttribute(range_key=True)
     picture = BinaryAttribute(null=True)
     zip_code = NumberAttribute(null=True)
@@ -211,11 +231,6 @@ class ModelTestCase(TestCase):
             if kwargs == {'table_name': UserModel.Meta.table_name}:
                 if scope_args['count'] == 0:
                     return HttpBadRequest(), {}
-                elif scope_args['count'] == 1:
-                    data = copy.copy(MODEL_TABLE_DATA)
-                    data['TableStatus'] = 'Creating'
-                    scope_args['count'] += 1
-                    return HttpOK(content=data), data
                 else:
                     return MODEL_TABLE_DATA
             else:
@@ -303,8 +318,8 @@ class ModelTestCase(TestCase):
             item = UserModel('foo', 'bar')
             self.assertEqual(item.email, 'needs_email')
             self.assertEqual(item.callable_field, 42)
-            self.assertEqual(repr(item), '{0}<{1}, {2}>'.format(UserModel.Meta.table_name, item.user_name, item.user_id))
-            self.assertEqual(repr(UserModel.get_meta_data()), 'MetaTable<{0}>'.format('Thread'))
+            self.assertEqual(repr(item), '{0}<{1}, {2}>'.format(UserModel.Meta.table_name, item.custom_user_name, item.user_id))
+            self.assertEqual(repr(UserModel._get_meta_data()), 'MetaTable<{0}>'.format('Thread'))
 
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK(SIMPLE_MODEL_TABLE_DATA), SIMPLE_MODEL_TABLE_DATA
@@ -314,6 +329,30 @@ class ModelTestCase(TestCase):
 
         self.assertRaises(ValueError, UserModel.from_raw_data, None)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), CUSTOM_ATTR_NAME_INDEX_TABLE_DATA
+            item = CustomAttrNameModel('foo', 'bar', overidden_attr='test')
+            self.assertEqual(item.overidden_attr, 'test')
+            self.assertTrue(not hasattr(item, 'foo_attr'))
+
+    def test_overidden_defaults(self):
+        """
+        Custom attribute names
+        """
+        schema = CustomAttrNameModel._get_schema()
+        correct_schema = {
+            'key_schema': [
+                {'key_type': 'HASH', 'attribute_name': 'user_name'},
+                {'key_type': 'RANGE', 'attribute_name': 'user_id'}
+            ],
+            'attribute_definitions': [
+                {'attribute_type': 'S', 'attribute_name': 'user_name'},
+                {'attribute_type': 'S', 'attribute_name': 'user_id'}
+            ]
+        }
+        self.assert_dict_lists_equal(correct_schema['key_schema'], schema['key_schema'])
+        self.assert_dict_lists_equal(correct_schema['attribute_definitions'], schema['attribute_definitions'])
+
     def test_refresh(self):
         """
         Model.refresh
@@ -371,6 +410,52 @@ class ModelTestCase(TestCase):
             args = req.call_args[1]
             self.assertEqual(args, params)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), None
+            item.delete(user_id='bar')
+            params = {
+                'key': {
+                    'user_id': {
+                        'S': 'bar'
+                    },
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'expected': {
+                    'user_id': {
+                        'Value': {'S': 'bar'},
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL',
+                'table_name': 'UserModel'
+            }
+            args = req.call_args[1]
+            self.assertEqual(args, params)
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), None
+            item.delete(user_id='bar')
+            params = {
+                'key': {
+                    'user_id': {
+                        'S': 'bar'
+                    },
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'expected': {
+                    'user_id': {
+                        'Value': {'S': 'bar'},
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL',
+                'table_name': 'UserModel'
+            }
+            args = req.call_args[1]
+            self.assertEqual(args, params)
+
     def test_update_item(self):
         """
         Model.update_item
@@ -413,6 +498,74 @@ class ModelTestCase(TestCase):
             }
             self.assertEqual(args, params)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {
+                ATTRIBUTES: {
+                    "views": {
+                        "N": "10"
+                    }
+                }
+            }
+            item.update_item('views', 10, action='add', user_name='foo')
+            args = req.call_args[1]
+            params = {
+                'table_name': 'SimpleModel',
+                'return_values': 'ALL_NEW',
+                'key': {
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'expected': {
+                    'user_name': {
+                        'Value': {'S': 'foo'}
+                    }
+                },
+                'attribute_updates': {
+                    'views': {
+                        'Action': 'ADD',
+                        'Value': {
+                            'N': '10'
+                        }
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL'
+            }
+            self.assertEqual(args, params)
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {
+                ATTRIBUTES: {
+                    "views": {
+                        "N": "10"
+                    }
+                }
+            }
+            item.update_item('views', 10, action='add', user_name__exists=False)
+            args = req.call_args[1]
+            params = {
+                'table_name': 'SimpleModel',
+                'return_values': 'ALL_NEW',
+                'key': {
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'expected': {
+                    'user_name': {'Exists': False}
+                },
+                'attribute_updates': {
+                    'views': {
+                        'Action': 'ADD',
+                        'Value': {
+                            'N': '10'
+                        }
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL'
+            }
+            self.assertEqual(args, params)
+
     def test_save(self):
         """
         Model.save
@@ -446,6 +599,93 @@ class ModelTestCase(TestCase):
 
             self.assertEqual(args, params)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {}
+            item.save(email__exists=False)
+            args = req.call_args[1]
+            params = {
+                'item': {
+                    'callable_field': {
+                        'N': '42'
+                    },
+                    'email': {
+                        'S': u'needs_email'
+                    },
+                    'user_id': {
+                        'S': u'bar'
+                    },
+                    'user_name': {
+                        'S': u'foo'
+                    },
+                },
+                'expected': {
+                    'email': {
+                        'Exists': False
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL',
+                'table_name': 'UserModel'
+            }
+            self.assertEqual(args, params)
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {}
+            item.save(user_name='bar')
+            args = req.call_args[1]
+            params = {
+                'item': {
+                    'callable_field': {
+                        'N': '42'
+                    },
+                    'email': {
+                        'S': u'needs_email'
+                    },
+                    'user_id': {
+                        'S': u'bar'
+                    },
+                    'user_name': {
+                        'S': u'foo'
+                    },
+                },
+                'expected': {
+                    'user_name': {
+                        'Value': {'S': 'bar'}
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL',
+                'table_name': 'UserModel'
+            }
+            self.assertEqual(args, params)
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {}
+            item.save(custom_user_name='foo')
+            args = req.call_args[1]
+            params = {
+                'item': {
+                    'callable_field': {
+                        'N': '42'
+                    },
+                    'email': {
+                        'S': u'needs_email'
+                    },
+                    'user_id': {
+                        'S': u'bar'
+                    },
+                    'user_name': {
+                        'S': u'foo'
+                    },
+                },
+                'expected': {
+                    'user_name': {
+                        'Value': {'S': 'foo'}
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL',
+                'table_name': 'UserModel'
+            }
+            self.assertEqual(args, params)
+
     def test_query(self):
         """
         Model.query
@@ -463,7 +703,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__between=['id-1', 'id-3']):
-                queried.append(item.serialize().get(RANGE))
+                queried.append(item._serialize().get(RANGE))
             self.assertListEqual(
                 [item.get('user_id').get(STRING_SHORT) for item in items],
                 queried
@@ -478,7 +718,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__gt='id-1', user_id__le='id-2'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -490,7 +730,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__lt='id-1'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -502,7 +742,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__ge='id-1'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -514,7 +754,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__le='id-1'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -526,7 +766,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__eq='id-1'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -538,7 +778,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo', user_id__begins_with='id'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         with patch(PATCH_METHOD) as req:
@@ -550,7 +790,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
             for item in UserModel.query('foo'):
-                queried.append(item.serialize())
+                queried.append(item._serialize())
             self.assertTrue(len(queried) == len(items))
 
         def fake_query(*args, **kwargs):
@@ -577,6 +817,15 @@ class ModelTestCase(TestCase):
             for item in UserModel.query('foo'):
                 self.assertIsNotNone(item)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), CUSTOM_ATTR_NAME_INDEX_TABLE_DATA
+            CustomAttrNameModel._get_meta_data()
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), {ITEMS: [CUSTOM_ATTR_NAME_ITEM_DATA.get(ITEM)]}
+            for item in CustomAttrNameModel.query('bar', overidden_user_name__eq='foo'):
+                self.assertIsNotNone(item)
+
     def test_scan(self):
         """
         Model.scan
@@ -594,7 +843,7 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             scanned_items = []
             for item in UserModel.scan():
-                scanned_items.append(item.serialize().get(RANGE))
+                scanned_items.append(item._serialize().get(RANGE))
             self.assertListEqual(
                 [item.get('user_id').get(STRING_SHORT) for item in items],
                 scanned_items
@@ -647,7 +896,7 @@ class ModelTestCase(TestCase):
                 'foo',
                 'bar'
             )
-            self.assertEqual(item.get_keys(), {'user_id': 'bar', 'user_name': 'foo'})
+            self.assertEqual(item._get_keys(), {'user_id': 'bar', 'user_name': 'foo'})
             params = {
                 'consistent_read': False,
                 'key': {
@@ -669,6 +918,21 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({}), {}
             self.assertRaises(UserModel.DoesNotExist, UserModel.get, 'foo', 'bar')
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), CUSTOM_ATTR_NAME_INDEX_TABLE_DATA
+            CustomAttrNameModel._get_meta_data()
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {}
+            self.assertRaises(CustomAttrNameModel.DoesNotExist, CustomAttrNameModel.get, 'foo', 'bar')
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), CUSTOM_ATTR_NAME_ITEM_DATA
+            item = CustomAttrNameModel.get('foo', 'bar')
+            self.assertEqual(item.overidden_attr, CUSTOM_ATTR_NAME_ITEM_DATA['Item']['foo_attr']['S'])
+            self.assertEqual(item.overidden_user_name, CUSTOM_ATTR_NAME_ITEM_DATA['Item']['user_name']['S'])
+            self.assertEqual(item.overidden_user_id, CUSTOM_ATTR_NAME_ITEM_DATA['Item']['user_id']['S'])
+
     def test_batch_get(self):
         """
         Model.batch_get
@@ -833,29 +1097,33 @@ class ModelTestCase(TestCase):
         """
         Models.Index.Query
         """
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), CUSTOM_ATTR_NAME_INDEX_TABLE_DATA
+            CustomAttrNameModel._get_meta_data()
+
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK(), INDEX_TABLE_DATA
-            IndexedModel.get_connection().describe_table()
+            IndexedModel._get_connection().describe_table()
 
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK(), LOCAL_INDEX_TABLE_DATA
-            LocalIndexedModel.get_meta_data()
+            LocalIndexedModel._get_meta_data()
 
         queried = []
         # user_id not valid
         with self.assertRaises(ValueError):
             for item in IndexedModel.email_index.query('foo', user_id__between=['id-1', 'id-3']):
-                queried.append(item.serialize().get(RANGE))
+                queried.append(item._serialize().get(RANGE))
 
         # startswith not valid
         with self.assertRaises(ValueError):
             for item in IndexedModel.email_index.query('foo', user_name__startswith='foo'):
-                queried.append(item.serialize().get(RANGE))
+                queried.append(item._serialize().get(RANGE))
 
         # name not valid
         with self.assertRaises(ValueError):
             for item in IndexedModel.email_index.query('foo', name='foo'):
-                queried.append(item.serialize().get(RANGE))
+                queried.append(item._serialize().get(RANGE))
 
         with patch(PATCH_METHOD) as req:
             items = []
@@ -867,8 +1135,8 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
 
-            for item in IndexedModel.email_index.query('foo', user_name__begins_with='bar'):
-                queried.append(item.serialize())
+            for item in IndexedModel.email_index.query('foo', limit=2, user_name__begins_with='bar'):
+                queried.append(item._serialize())
 
             params = {
                 'key_conditions': {
@@ -891,7 +1159,8 @@ class ModelTestCase(TestCase):
                 },
                 'index_name': 'email_index',
                 'table_name': 'IndexedModel',
-                'return_consumed_capacity': 'TOTAL'
+                'return_consumed_capacity': 'TOTAL',
+                'limit': 2
             }
             self.assertEqual(req.call_args[1], params)
 
@@ -905,8 +1174,8 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK({'Items': items}), {'Items': items}
             queried = []
 
-            for item in LocalIndexedModel.email_index.query('foo', user_name__begins_with='bar'):
-                queried.append(item.serialize())
+            for item in LocalIndexedModel.email_index.query('foo', limit=1, user_name__begins_with='bar'):
+                queried.append(item._serialize())
 
             params = {
                 'key_conditions': {
@@ -929,7 +1198,46 @@ class ModelTestCase(TestCase):
                 },
                 'index_name': 'email_index',
                 'table_name': 'LocalIndexedModel',
-                'return_consumed_capacity': 'TOTAL'
+                'return_consumed_capacity': 'TOTAL',
+                'limit': 1
+            }
+            self.assertEqual(req.call_args[1], params)
+
+        with patch(PATCH_METHOD) as req:
+            items = []
+            for idx in range(10):
+                item = copy.copy(GET_MODEL_ITEM_DATA.get(ITEM))
+                item['user_name'] = {STRING_SHORT: 'id-{0}'.format(idx)}
+                items.append(item)
+            req.return_value = HttpOK({'Items': items}), {'Items': items}
+            queried = []
+
+            for item in CustomAttrNameModel.uid_index.query('foo', limit=2, user_name__begins_with='bar'):
+                queried.append(item._serialize())
+
+            params = {
+                'key_conditions': {
+                    'user_name': {
+                        'ComparisonOperator': 'BEGINS_WITH',
+                        'AttributeValueList': [
+                            {
+                                'S': u'bar'
+                            }
+                        ]
+                    },
+                    'user_id': {
+                        'ComparisonOperator': 'EQ',
+                        'AttributeValueList': [
+                            {
+                                'S': u'foo'
+                            }
+                        ]
+                    }
+                },
+                'index_name': 'uid_index',
+                'table_name': 'CustomAttrModel',
+                'return_consumed_capacity': 'TOTAL',
+                'limit': 2
             }
             self.assertEqual(req.call_args[1], params)
 
@@ -937,29 +1245,18 @@ class ModelTestCase(TestCase):
         """
         Models.GlobalSecondaryIndex
         """
-        self.assertIsNotNone(IndexedModel.email_index.hash_key_attribute())
+        self.assertIsNotNone(IndexedModel.email_index._hash_key_attribute())
         self.assertEqual(IndexedModel.email_index.Meta.projection.projection_type, AllProjection.projection_type)
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK(), INDEX_TABLE_DATA
             with self.assertRaises(ValueError):
                 IndexedModel('foo', 'bar')
-            IndexedModel.get_meta_data()
+            IndexedModel._get_meta_data()
 
         scope_args = {'count': 0}
 
         def fake_dynamodb(obj, **kwargs):
-            if kwargs == {'table_name': UserModel.Meta.table_name}:
-                if scope_args['count'] == 0:
-                    return HttpBadRequest(), {}
-                elif scope_args['count'] == 1:
-                    data = copy.copy(MODEL_TABLE_DATA)
-                    data['TableStatus'] = 'Creating'
-                    scope_args['count'] += 1
-                    return HttpOK(content=data), data
-                else:
-                    return MODEL_TABLE_DATA
-            else:
-                return HttpOK(content={}), {}
+            return HttpOK(content={}), {}
 
         fake_db = MagicMock()
         fake_db.side_effect = fake_dynamodb
@@ -1004,7 +1301,7 @@ class ModelTestCase(TestCase):
 
         scope_args = {'count': 0}
 
-        schema = IndexedModel.get_indexes()
+        schema = IndexedModel._get_indexes()
 
         expected = {
             'local_secondary_indexes': [
@@ -1049,25 +1346,14 @@ class ModelTestCase(TestCase):
         self.assertEqual(schema['local_secondary_indexes'][0]['projection']['NonKeyAttributes'], ['numbers'])
 
         def fake_dynamodb(obj, **kwargs):
-            if kwargs == {'table_name': UserModel.Meta.table_name}:
-                if scope_args['count'] == 0:
-                    return HttpBadRequest(), {}
-                elif scope_args['count'] == 1:
-                    data = copy.copy(MODEL_TABLE_DATA)
-                    data['TableStatus'] = 'Creating'
-                    scope_args['count'] += 1
-                    return HttpOK(content=data), data
-                else:
-                    return MODEL_TABLE_DATA
-            else:
-                return HttpOK(content={}), {}
+            return HttpOK(content={}), {}
 
         fake_db = MagicMock()
         fake_db.side_effect = fake_dynamodb
 
         with patch(PATCH_METHOD, new=fake_db) as req:
             LocalIndexedModel.create_table(read_capacity_units=2, write_capacity_units=2)
-            params = {
+            params = collections.OrderedDict({
                 'attribute_definitions': [
                     {
                         'attribute_name': 'email', 'attribute_type': 'S'
@@ -1085,12 +1371,11 @@ class ModelTestCase(TestCase):
                         'AttributeName': 'numbers', 'KeyType': 'RANGE'
                     }
                 ]
-            }
+            })
             schema = LocalIndexedModel.email_index.get_schema()
             args = req.call_args[1]
+            self.assertEqual(schema, collections.OrderedDict(params))
             self.assertTrue('ProvisionedThroughput' not in args['local_secondary_indexes'][0])
-            self.assert_dict_lists_equal(schema['key_schema'], params['key_schema'])
-            self.assert_dict_lists_equal(params['attribute_definitions'], schema['attribute_definitions'])
 
     def test_projections(self):
         """
@@ -1138,7 +1423,7 @@ class ModelTestCase(TestCase):
         Display warning for pre v1.0 Models
         """
         with self.assertRaises(AttributeError):
-            OldStyleModel.get_meta_data()
+            OldStyleModel._get_meta_data()
 
         with self.assertRaises(AttributeError):
             OldStyleModel.exists()
